<?php
	$_SESSION['nume_slogan'] = 'Slogan';
	$_SESSION['nume_antet'] = 'antet';
	
	$_SESSION['nume_pag1'] = 'Acasa';
	$_SESSION['nume_pag2'] = 'Informatii';
	$_SESSION['nume_pag3'] = 'Transparenta';
	$_SESSION['nume_pag4'] = 'Convocari';
	$_SESSION['nume_pag5'] = 'Contact';
	
	$_SESSION['textareacontinut1'] = 'Asociatia de Dezvoltare Intercomunitara Giurgiu Rutier';
	$_SESSION['textareacontinut2'] = 'Asociatia de Dezvoltare Intercomunitara Giurgiu Rutier';
	$_SESSION['textareacontinut3'] = 'Asociatia de Dezvoltare Intercomunitara Giurgiu Rutier';
	$_SESSION['textareacontinut4'] = 'Asociatia de Dezvoltare Intercomunitara Giurgiu Rutier';
	$_SESSION['textareacontinut5'] = '<div>Asociatia de Dezvoltare Intercomunitara Giurgiu Rutier</div><div><br></div><div>Adresa : Giurgiu, Romania</div><div>Contact : adi_giurgiurutier@yahoo.com</div>';
	
	$_SESSION['nume_utilizator'] = 'Administrator';
	$_SESSION['parola'] = 'Parola_123';
	$_SESSION['email'] = 'stefanfloringr@gmail.com';  
?>
