<?php session_start(); include "session.php" ; ?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<HTML>
 <HEAD>
 <TITLE>Asociatia de Dezvoltare Intercomunitara Giurgiu Rutier - Slogan</TITLE>
	<META NAME="Keywords" CONTENT="Asociatia de Dezvoltare Intercomunitara Giurgiu Rutier - Slogan" />
	<META NAME="Description" CONTENT="Asociatia de Dezvoltare Intercomunitara Giurgiu Rutier - Slogan" />  
	<META http-equiv="Content-Type" content="text/html; charset=utf-8" />
	<META NAME="Generator" CONTENT="NOTEPAD">
	<META NAME="Author" CONTENT="stefanfloringr@gmail.com">
	<meta name = "language" content = "ro" /> 
	<meta name = "revisit-after" content = "1 day" /> 
	<meta name = "document-rating" content = "General" />
	<link rel="stylesheet" href="style.css"  type="text/css" media="screen" />
	<script src="nicEdit/nicEdit.js" type="text/javascript"></script>
	<script>bkLib.onDomLoaded(function(){var myInstance = new nicEditor().panelInstance("textareacontinut");myInstance.addEvent("blur", function() {});});</script>
	
 </HEAD>
<BODY>
	<table class="all" >
		<tr>
			<td colspan="2" ><?php include "header.php"; ?>	</td>
		</tr>
		<tr>
			<td colspan="2" id="td"><?php include "meniu_orizontal.php"; ?></td>
		</tr>
		<tr>
			<td id="stanga">
					<?php include "continut.php"; ?>
			</td>
			<td id="dreapta">
					<?php include "dreapta.php"; ?>
			</td>
		</tr>
		<tr>
			<td id="footer" colspan="2">
				<?php include "footer.php"; ?> 
			</td>
		</tr>
	</table> 
</BODY>
</HTML>