body{
	background-color: #FFFFFF;
	background: url(img/bg_.jpg) repeat fixed center top;
	font-family: Verdana, Courier new, arial;
	font-size: 14px;
	color: #000000; 
	text-align: left;
}
p {
	text-indent: 20px;
	margin-top:8px; 
	margin-bottom:8px; 
}
.all{
	width: 1000px; 
	padding: 4px;
	vertical-align:top;
	text-align:left;
	margin-left:auto;
	margin-right:auto; 
	border: solid thin #7D85DA;
		-webkit-border-radius: .4em;
		-moz-border-radius: .4em;
		border-radius: .4em;
		-webkit-box-shadow: 1px 1px 1px #ffffff; 
		box-shadow: 1px 1px 20px #7D85DA;
}
#header{
	width:100%; 
	height:200px;
	text-align: center;
	vertical-align: middle;
	font-family: Verdana, Courier new, arial;
	font-size: 18px;
	color: #000000; 
	border: solid thin #ffffff;
		-webkit-border-radius: .4em;
		-moz-border-radius: .4em;
		border-radius: .4em;
		-webkit-box-shadow: 1px 1px 1px #ffffff; 
		box-shadow: 1px 1px 20px #ffffff;
}
#casetaheader{
	width:100%; 
	vertical-align: middle;
}
#headerstanga{
	width:250px; 
	height:200px;
	margin-right:10px; 
	text-align: center;
	line-height: 1.5;
	vertical-align: middle;
	padding: 8px;
	*border: solid thin #2C5F2D;
	*-webkit-border-radius: .4em;
	*-moz-border-radius: .4em;
	*border-radius: .4em;
	*-webkit-box-shadow: 1px 1px 1px #ffffff; 
	*box-shadow: 1px 1px 20px #2C5F2D;
}
#headerdreapta{
	height:200px;
	padding: 8px;
	text-align: center;
	font-family: Verdana, Courier new, arial;
	font-size: 16px;
	font-weight: bold;
	color: #000000; 
	*border: solid thin #7D85DA;
		-webkit-border-radius: .4em;
		-moz-border-radius: .4em;
		border-radius: .4em;
}
#butonmeniu{  
	width:160px;
	float: left;
	font-family: arial;
	font-size: 16px;
	text-align: center;
	padding: 15px;
	margin-top: 10px;
	margin-left: 4px;
	margin-bottom: 10px;
	background-color : #F8FFEC;
	border: solid thin #2C5F2D;
	-webkit-border-radius: .4em;
	-moz-border-radius: .4em;
	border-radius: .4em;
	-webkit-box-shadow: 1px 1px 1px #ffffff; 
	box-shadow: 1px 1px 10px #2C5F2D;
}
#stanga{
	width:680px; 
	height: 800px;
	padding: 20px;
	vertical-align: top;
	margin-top: 4px;
	line-height: 18px;
	background-color: #FFFFFF;
	border: solid thin #2C5F2D;
	-webkit-border-radius: .4em;
	-moz-border-radius: .4em;
	border-radius: .4em;
	-webkit-box-shadow: 1px 1px 1px #ffffff; 
	box-shadow: 1px 1px 10px #2C5F2D;
}
#numepagina{
	font-family: Verdana, Courier new, arial;
	font-size: 22px;
	font-weight: bold;
	color: #000000; 
}
#dreapta{
	vertical-align: top;
	margin-top: 4px;
	margin-bottom: 4px;
	background-color: #FFFFFF;
	border: solid thin #2C5F2D;
	-webkit-border-radius: .4em;
	-moz-border-radius: .4em;
	border-radius: .4em;
	-webkit-box-shadow: 1px 1px 1px #ffffff; 
	box-shadow: 1px 1px 10px #2C5F2D;
}
#formular{
	
}
#codsecuritate{
	width:60px;
	font-family: Verdana, Courier new, arial;
	font-size: 14px;
	color: #000000; 
	padding: 6px;
	text-align: left;
	background-color : #F8FFEC;
	border: solid thin #c1c1c1;
	-webkit-border-radius: .4em;
	-moz-border-radius: .4em;
	border-radius: .4em;
	-webkit-box-shadow: 1px 1px 1px #ffffff; 
	box-shadow: 1px 1px 10px #ffffff;
}
#campdreapta{
	width:220px;
	font-family: Verdana, Courier new, arial;
	font-size: 14px;
	color: #000000; 
	padding: 6px;
	text-align: left;
	background-color : #F8FFEC;
	border: solid thin #c1c1c1;
	-webkit-border-radius: .4em;
	-moz-border-radius: .4em;
	border-radius: .4em;
	-webkit-box-shadow: 1px 1px 1px #ffffff; 
	box-shadow: 1px 1px 10px #ffffff;
}

#textareadreapta{
	width:228px;
	height: 200px;
	font-family: Verdana, Courier new, arial;
	font-size: 14px;
	color: #000000; 
	text-align: left;
	background-color : #F8FFEC;
	border: solid thin #c1c1c1;
	-webkit-border-radius: .4em;
	-moz-border-radius: .4em;
	border-radius: .4em;
	-webkit-box-shadow: 1px 1px 1px #ffffff; 
	box-shadow: 1px 1px 10px #ffffff;
}
#butonsubmit{
	padding: 15px;
	margin: 10px;
	text-align:center;
	line-height: 20px;
	font-family: Verdana, Courier new, arial;
	font-size: 14px;
	color: blue; 
	background-color: #F8FFEC;
	border: solid thin blue;
		-webkit-border-radius: .4em;
		-moz-border-radius: .4em;
		border-radius: .4em;
}
#foto{
width: 670px; 
height: 200px;
padding: 8px;
text-align:center;
border: solid thin #2C5F2D;
	-webkit-border-radius: .4em;
	-moz-border-radius: .4em;
	border-radius: .4em;
	-webkit-box-shadow: 1px 1px 1px #ffffff; 
	box-shadow: 1px 1px 20px #2C5F2D;
}
#footer{
	width:100%; 
	height:40px;
	margin:10px; 
	text-align: center;
	vertical-align: middle;
	font-family: Verdana, Courier new, arial;
	font-size: 14px;
	color: #000000; 
	background-color: #FFFFFF;
	border: solid thin #2C5F2D;
	-webkit-border-radius: .4em;
	-moz-border-radius: .4em;
	border-radius: .4em;
	-webkit-box-shadow: 1px 1px 1px #ffffff; 
	box-shadow: 1px 1px 10px #2C5F2D;
}
a:link{
	text-decoration: none;
	color: #000000;
}
a:visited{
	text-decoration: none;
	color: blue;
}
a:hover{
	color: #000000;
	background-color: none;
}
a:active{
	text-decoration: none;
	color: blue;
}