
<?php
if ($_GET["pag"] == "" or $_GET["pag"] == "1"){
	echo'<p id="numepagina">'.$_SESSION['nume_pag1'].'</p>
		<br /
	<p>'.$_SESSION['textareacontinut1'].'</p>';
}
if ($_GET["pag"] == "2"){
	echo'<p id="numepagina">'.$_SESSION['nume_pag2'].'</p>
		<br />
	<p>'.$_SESSION['textareacontinut2'].'</p>';
}
if ($_GET["pag"] == "3"){
	echo'<p id="numepagina">'.$_SESSION['nume_pag3'].'</p>
		<br />
	<p>'.$_SESSION['textareacontinut3'].'</p>';
}
if ($_GET["pag"] == "4"){
	echo'<p id="numepagina">'.$_SESSION['nume_pag4'].'</p>
		<br />
	<p>'.$_SESSION['textareacontinut4'].'</p>';
}
if ($_GET["pag"] == "5"){
	echo'<p id="numepagina">'.$_SESSION['nume_pag5'].'</p>
		<br />
	<p>'.$_SESSION['textareacontinut5'].'</p>';
}
?>
