<?php
echo'
	<a href="index.php?pag=1" alt="asociatiadedezvoltareintercomunitaragiurgiurutier - '.$_SESSION['nume_pag1'].'" title="asociatiadedezvoltareintercomunitaragiurgiurutier - '.$_SESSION['nume_pag1'].'">
		<div id="butonmeniu">'.$_SESSION['nume_pag1'].'</div>
	</a>
	<a href="index.php?pag=2" alt="asociatiadedezvoltareintercomunitaragiurgiurutier - '.$_SESSION['nume_pag2'].'" title="asociatiadedezvoltareintercomunitaragiurgiurutier - '.$_SESSION['nume_pag2'].'">
		<div id="butonmeniu">'.$_SESSION['nume_pag2'].'</div>
	</a>
	<a href="index.php?pag=3" alt="asociatiadedezvoltareintercomunitaragiurgiurutier - '.$_SESSION['nume_pag3'].'" title="asociatiadedezvoltareintercomunitaragiurgiurutier - '.$_SESSION['nume_pag3'].'">
		<div id="butonmeniu">'.$_SESSION['nume_pag3'].'</div>
	</a>
	<a href="index.php?pag=4" alt="asociatiadedezvoltareintercomunitaragiurgiurutier - '.$_SESSION['nume_pag4'].'" title="asociatiadedezvoltareintercomunitaragiurgiurutier - '.$_SESSION['nume_pag4'].'">
		<div id="butonmeniu">'.$_SESSION['nume_pag4'].'</div>
	</a>
	<a href="index.php?pag=5" alt="asociatiadedezvoltareintercomunitaragiurgiurutier - '.$_SESSION['nume_pag5'].'" title="asociatiadedezvoltareintercomunitaragiurgiurutier - '.$_SESSION['nume_pag5'].'">
		<div id="butonmeniu">'.$_SESSION['nume_pag5'].'</div>
	</a>';
?>
