
<table id="casetaheader">
	<tr>
		<td id="headerstanga">
			<?php
				echo'Asociatia de Dezvoltare Intercomunitara "Giurgiu Rutier"';
			?>	
		</td>
		<td id="headerdreapta">
			<?php
				echo '<a href="http://'.$_SERVER['SERVER_NAME'].'">
					<img id="foto" alt="'.$_SERVER['SERVER_NAME'].'" title="'.$_SERVER['SERVER_NAME'].'" src="http://'.$_SERVER['SERVER_NAME'].'/img/sigla-adi-giurgiu-rutier-1.jpg" />
					</a>';
			?>					
		</td>
	<tr>
</table>